==> qtjambi-datavisualization-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiDataVisualization/QItemModelBarDataProxy_shell.h <==
#ifndef QITEMMODELBARDATAPROXY_SHELL_H
#define QITEMMODELBARDATAPROXY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDataVisualization/qitemmodelbardataproxy.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDataVisualization/qabstractdataproxy.h>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/qbardataitem.h>
#include <QtDataVisualization/qbardataproxy.h>
#include <QtJambi/RegistryAPI>


class QItemModelBarDataProxy_shell : public QtDataVisualization::QItemModelBarDataProxy, public QtJambiShellInterface
{
public:
    QItemModelBarDataProxy_shell(QAbstractItemModel* itemModel0, QObject* parent1 = nullptr);
    QItemModelBarDataProxy_shell(QAbstractItemModel* itemModel0, const QString& valueRole1, QObject* parent2 = nullptr);
    QItemModelBarDataProxy_shell(QAbstractItemModel* itemModel0, const QString& rowRole1, const QString& columnRole2, const QString& valueRole3, QObject* parent4 = nullptr);
    QItemModelBarDataProxy_shell(QAbstractItemModel* itemModel0, const QString& rowRole1, const QString& columnRole2, const QString& valueRole3, const QString& rotationRole4, QObject* parent5 = nullptr);
    QItemModelBarDataProxy_shell(QAbstractItemModel* itemModel0, const QString& rowRole1, const QString& columnRole2, const QString& valueRole3, const QString& rotationRole4, const QStringList& rowCategories5, const QStringList& columnCategories6, QObject* parent7 = nullptr);
    QItemModelBarDataProxy_shell(QAbstractItemModel* itemModel0, const QString& rowRole1, const QString& columnRole2, const QString& valueRole3, const QStringList& rowCategories4, const QStringList& columnCategories5, QObject* parent6 = nullptr);
    QItemModelBarDataProxy_shell(QObject* parent0 = nullptr);
    ~QItemModelBarDataProxy_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QItemModelBarDataProxy_access : public QtDataVisualization::QItemModelBarDataProxy
{
};

#endif // QITEMMODELBARDATAPROXY_SHELL_H

==> qtjambi-datavisualization-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiDataVisualization/QItemModelBarDataProxy_shell.h <==
#ifndef QITEMMODELBARDATAPROXY_SHELL_H
#define QITEMMODELBARDATAPROXY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDataVisualization/qitemmodelbardataproxy.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDataVisualization/qabstractdataproxy.h>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/qbardataitem.h>
#include <QtDataVisualization/qbardataproxy.h>
#include <QtJambi/RegistryAPI>


class QItemModelBarDataProxy_shell : public QItemModelBarDataProxy, public QtJambiShellInterface
{
public:
    QItemModelBarDataProxy_shell(QAbstractItemModel* itemModel0, QObject* parent1 = nullptr);
    QItemModelBarDataProxy_shell(QAbstractItemModel* itemModel0, const QString& valueRole1, QObject* parent2 = nullptr);
    QItemModelBarDataProxy_shell(QAbstractItemModel* itemModel0, const QString& rowRole1, const QString& columnRole2, const QString& valueRole3, QObject* parent4 = nullptr);
    QItemModelBarDataProxy_shell(QAbstractItemModel* itemModel0, const QString& rowRole1, const QString& columnRole2, const QString& valueRole3, const QString& rotationRole4, QObject* parent5 = nullptr);
    QItemModelBarDataProxy_shell(QAbstractItemModel* itemModel0, const QString& rowRole1, const QString& columnRole2, const QString& valueRole3, const QString& rotationRole4, const QStringList& rowCategories5, const QStringList& columnCategories6, QObject* parent7 = nullptr);
    QItemModelBarDataProxy_shell(QAbstractItemModel* itemModel0, const QString& rowRole1, const QString& columnRole2, const QString& valueRole3, const QStringList& rowCategories4, const QStringList& columnCategories5, QObject* parent6 = nullptr);
    QItemModelBarDataProxy_shell(QObject* parent0 = nullptr);
    ~QItemModelBarDataProxy_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QItemModelBarDataProxy_access : public QItemModelBarDataProxy
{
};

#endif // QITEMMODELBARDATAPROXY_SHELL_H
